import { DOMEvent } from "@/helpers";

type UpdatingEvent = "onBlur" | "onChange" | "onInput";
type FormFieldHelperOptions<T> = {
    event: UpdatingEvent
}

export function formFieldProps<T>(subject: T, update: (value: T) => void, options: Partial<FormFieldHelperOptions<T>> = {}) {
    const {
        event = "onChange"
    } = options;

    return <P extends keyof T, TArgs extends any[]>(
        field: P,
        extractor: (...args: TArgs) => T[P] = ((event: DOMEvent<HTMLInputElement>) => event.target.value as unknown as T[P]) as any
    ) => ({
        value: subject[field],
        [event]: (...args: TArgs) => update({
            ...subject,
            [field]: extractor(...args),
        } as T)
    })
}
